@@ -32,11 +32,7 @@ Terminal::Terminal(const QString &workingDir, QWidget *parent)
     m_availableTerminalId++;
     m_parentSplitter = parent;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    KPluginMetaData part(QStringLiteral("konsolepart"));
-#else
     KPluginMetaData part(QStringLiteral("kf6/parts/konsolepart"));
-#endif
 
     m_part = KParts::PartLoader::instantiatePart<KParts::Part>(part, parent).plugin;
 
@@ -76,10 +72,10 @@ Terminal::Terminal(const QString &workingDir, QWidget *parent)
 
         disableOffendingPartActions();
 
-        m_terminalInterface = qobject_cast<TerminalInterfaceV2 *>(m_part);
+        m_terminalInterface = qobject_cast<TerminalInterface *>(m_part);
 
         if (!m_terminalInterface) {
-            qFatal("Version of Konsole is outdated. Konsole didn't return a valid TerminalInterfaceV2.");
+            qFatal("Version of Konsole is outdated. Konsole didn't return a valid TerminalInterface.");
             return;
         }
 
